:mod:`langacore.kit.concurrency.synchronization`
================================================


.. automodule:: langacore.kit.concurrency.synchronization

.. note::

  Instead of importing the whole structure, a recommended shortcut is available.
  Use ``from langacore.kit.concurrency import synchronized``.

Functions
----------

.. autofunction:: synchronized
